powered by
ID, name, birth date, birth city among other informations are returned.
fetch_deputado(id = NULL, nome = NULL, idLegislatura = NULL, siglaUf = NULL, siglaPartido = NULL, siglaSexo = NULL, itens = NULL, ordenarPor = NULL)
Deputy's ID
Deputy's name (partially or complete)
Id of one or more mandates of the deputy
State's abbreviation of the deputy
Party's abbreviation of the deputy
Gender's abbreviation
Items quantity. '-1' returns all current deputies at the request moment
Element that will be used to sort the returned list
Dataframe containing details about the deputy.
# NOT RUN { abel_mesquita_info <- fetch_deputado(id = 178957) # }
Run the code above in your browser using DataLab