Learn R Programming

rcongresso (version 0.4.6)

fetch_id_partido: Retrieves the party's ID from its abbreviation.

Description

The function can be used to fetch a vector of ids as well, in case of many parties.

Usage

fetch_id_partido(sigla)

Arguments

sigla

Party's abbreviation

Value

Party's ID.

See Also

fetch_id_proposicao

Examples

Run this code
# NOT RUN {
p <- fetch_id_partido(c("PT","PSDB","PP","PMDB"))
# }

Run the code above in your browser using DataLab