Learn R Programming

rcongresso (version 0.4.6)

fetch_id_proposicao: Retrieves the proposition ID from its type, number and year

Description

The function can be used to fetch a vector of ids as well, in case of many propositions.

Usage

fetch_id_proposicao(tipo, numero, ano)

Arguments

tipo

Proposition type (i.e., PEC, PL, PDC)

numero

Proposition number

ano

Proposition year

Value

Proposition's ID.

See Also

fetch_id_partido

Examples

Run this code
# NOT RUN {
pec241_id <- fetch_id_proposicao("PEC", 241, 2016)
# }

Run the code above in your browser using DataLab