Learn R Programming

rcongresso (version 0.4.6)

fetch_orientacoes: Fetches the positions of a group on a voting

Description

Fetch how the groups in the chamber of deputies instructed their members to vote on a given voting.

Usage

fetch_orientacoes(id_votacao = NULL)

Arguments

id_votacao

Voting's ID

Value

Dataframe containing the groups and their votes

See Also

get_votos_partidos

Examples

Run this code
# NOT RUN {
orientacoes_pec241 <- fetch_orientacoes(7252)
# }

Run the code above in your browser using DataLab