Learn R Programming

rcongresso (version 0.4.6)

fetch_proposicao_from_votacao: Finds the id of the proposition to which a given voting refers

Description

Finds the id of the proposition to which a given voting refers.

Usage

fetch_proposicao_from_votacao(id_votacao = NULL)

Arguments

id_votacao

Voting's ID

Value

Dataframe containing proposition details

Examples

Run this code
# NOT RUN {
pec241 <- fetch_proposicao_from_votacao(7252)
# }

Run the code above in your browser using DataLab