Learn R Programming

rcongresso (version 0.4.6)

fetch_votacao: Fetches details about a voting

Description

Fetches details about a voting.

Usage

fetch_votacao(id_votacao = NULL)

Arguments

id_votacao

Voting's ID

Value

Dataframe containing details about a voting, including tittle, start voting time, finish voting time, result and approval

See Also

fetch_votos

Examples

Run this code
# NOT RUN {
segundoturno_pec241 <- fetch_votacao(7252)
# }

Run the code above in your browser using DataLab