Learn R Programming

rcongresso (version 0.4.6)

fetch_votacoes: Fetches all the votings which a proposition went through

Description

Returns all the votings related to a proposition by its id.

Usage

fetch_votacoes(id_prop)

Arguments

id_prop

Proposition's ID

Value

Dataframe containing all the votings.

See Also

fetch_id_proposicao, fetch_proposicao_from_votacao

Examples

Run this code
# NOT RUN {
votacoes_pec241 <- fetch_votacoes(2088351)
# }

Run the code above in your browser using DataLab