Learn R Programming

rcongresso (version 0.4.6)

fetch_votos: Fetches individual votes from a voting

Description

Some other informations about the deputy are returned, such as: name, party, id.

Usage

fetch_votos(id_votacao = NULL)

Arguments

id_votacao

Voting's ID

Value

Dataframe containing votes for each deputy on this voting.

Details

DETAILS

See Also

fetch_votacao

Examples

Run this code
# NOT RUN {
votos_pec241 <- fetch_votos(7252)
# }

Run the code above in your browser using DataLab