Learn R Programming

rcongresso (version 0.4.6)

get_votos_partidos: Fetches the positions by party on a voting

Description

Fetch how parties in the chamber of deputies instructed their members to vote on a given voting.

Usage

get_votos_partidos(votacao = NULL)

Arguments

votacao

Voting's id

Value

Dataframe with each party's orientation for its deputies.

See Also

fetch_orientacoes

Examples

Run this code
# NOT RUN {
pos_partidos <- get_votos_partidos(7252)
# }

Run the code above in your browser using DataLab