Learn R Programming

rcongresso (version 0.4.6)

ultima_votacao: Gets the last voting on a given voting

Description

Filters only the last voting from each proposition in the dataframe.

Usage

ultima_votacao(votacoes = NULL)

Arguments

votacoes

Dataframe containing all the votings related to a proposition

Value

Dataframe containing only the last voting related to a proposition

Examples

Run this code
# NOT RUN {
votacoes_pec241 <- fetch_votacoes(2088351)
ultima_votacao <- ultima_votacao(votacoes_pec241)
# }

Run the code above in your browser using DataLab