powered by
The function can be used to fetch a vector of ids as well, in case of many parties.
fetch_id_partido(sigla)
Party's abbreviation
Party's ID.
fetch_id_proposicao
# NOT RUN { p <- fetch_id_partido(c("PT","PSDB","PP","PMDB")) # }
Run the code above in your browser using DataLab