powered by
The function can be used to fetch a vector of ids as well, in case of many propositions.
fetch_id_proposicao(tipo, numero, ano)
Proposition type (i.e., PEC, PL, PDC)
Proposition number
Proposition year
Proposition's ID.
fetch_id_partido
# NOT RUN { pec241_id <- fetch_id_proposicao("PEC", 241, 2016) # }
Run the code above in your browser using DataLab