powered by
Fetch how the groups in the chamber of deputies instructed their members to vote on a given voting.
fetch_orientacoes(id_votacao = NULL)
Voting's ID
Dataframe containing the groups and their votes
get_votos_partidos
# NOT RUN { orientacoes_pec241 <- fetch_orientacoes(7252) # }
Run the code above in your browser using DataLab