fetch_partido: Fetches parties from API using a query.
Description
Returns a list containing basic information about parties which has or had been any deputy
in the lower house. If none parameters are passed, the function returns the parties
which has active deputies on that moment.
Items quantity. '-1' returns all parties which have
deputies at the request moment
ordenarPor
Order by: 'id', 'sigla' or 'nome'
Value
Dataframe containing information about the parties.
Details
Note that if you have the party's ID, it's not necessary to add any other parameter on the
function call. The call to this function using the party's ID returns more details than using the
others parameters. If you don't have the party's ID, the fetch_id_partido
function may be helpful.