fetch_proposicao: Fetches proposition from API using a query
Description
Fetches information about law's projects, resolutions, provisional measures,
law amendments, opinions and all the other propositions types on the
Deputies' Chamber.
Several parameters can be used to select and filter the final result. By default, the function
returns all the proposition which were presented or had some situation change in the last
15 days.
Items quantity. '-1' returns all the propositions which had been processed
in the last 30 days
Value
Dataframe containing information about the proposition.
Details
Note that if you have the proposition's ID, it's not necessary to add any other parameter on the
function call. The call to this function using the proposition's ID returns more details than using the
others parameters. If you don't have the proposition's ID, the fetch_id_proposicao
function may be helpful.