powered by
Fetches details about a voting.
fetch_votacao(id_votacao = NULL)
Voting's ID
Dataframe containing details about a voting, including tittle, start voting time, finish voting time, result and approval
fetch_votos
# NOT RUN { segundoturno_pec241 <- fetch_votacao(7252) # }
Run the code above in your browser using DataLab