powered by
Some other informations about the deputy are returned, such as: name, party, id.
fetch_votos(id_votacao = NULL)
Voting's ID
Dataframe containing votes for each deputy on this voting.
DETAILS
fetch_votacao
# NOT RUN { votos_pec241 <- fetch_votos(7252) # }
Run the code above in your browser using DataLab