powered by
Fetch how parties in the chamber of deputies instructed their members to vote on a given voting.
get_votos_partidos(votacao = NULL)
Voting's id
Dataframe with each party's orientation for its deputies.
fetch_orientacoes
# NOT RUN { pos_partidos <- get_votos_partidos(7252) # }
Run the code above in your browser using DataLab