powered by
Filters only the last voting from each proposition in the dataframe.
ultima_votacao(votacoes = NULL)
Dataframe containing all the votings related to a proposition
Dataframe containing only the last voting related to a proposition
# NOT RUN { votacoes_pec241 <- fetch_votacoes(2088351) ultima_votacao <- ultima_votacao(votacoes_pec241) # }
Run the code above in your browser using DataLab